@@ -10,7 +10,6 @@ import itertools
 from pathlib import Path
 
 from cgt_calc.exceptions import (
-    ExchangeRateMissingError,
     ParsingError,
     SymbolMissingError,
     UnexpectedColumnCountError,
@@ -38,7 +37,7 @@ class AwardPrices:
                 and symbol in self.award_prices[to_search]
             ):
                 return self.award_prices[to_search][symbol]
-        raise ExchangeRateMissingError(symbol, date)
+        raise Exception(f"Award price is not found for symbol {symbol} for date {date}")
 
 
 def action_from_str(label: str) -> ActionType:
@@ -84,6 +83,15 @@ def action_from_str(label: str) -> ActionType:
     if label == "Credit Interest":
         return ActionType.INTEREST
 
+    if label == "Reinvest Shares":
+        return ActionType.REINVEST_SHARES
+
+    if label == "Reinvest Dividend":
+        return ActionType.REINVEST_DIVIDENDS
+
+    if label == "Wire Funds Received":
+        return ActionType.WIRE_FUNDS_RECEIVED
+
     raise ParsingError("schwab transactions", f"Unknown action: {label}")
 
 
@@ -156,6 +164,27 @@ def read_schwab_transactions(
     try:
         with Path(transactions_file).open(encoding="utf-8") as csv_file:
             lines = list(csv.reader(csv_file))
+
+            if "Transactions" not in lines[0][0]:
+                raise ParsingError(
+                    transactions_file,
+                    "First line of Schwab transactions file must be something like "
+                    "'Transactions for account ...'",
+                )
+
+            if len(lines[1]) != 9:
+                raise ParsingError(
+                    transactions_file,
+                    "Second line of Schwab transactions file must be a header"
+                    " with 9 columns",
+                )
+
+            if "Total" not in lines[-1][0]:
+                raise ParsingError(
+                    transactions_file,
+                    "Last line of Schwab transactions file must be total",
+                )
+
             # Remove headers and footer
             lines = lines[2:-1]
             transactions = [
